<!DOCTYPE html>
<html lang="fa" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>تبدیل متن به خطوط باستانی</title>
    <link rel="stylesheet" href="{{ url_for('static', filename='styles.css') }}">
    <link rel="apple-touch-icon" sizes="48x48" href="{{ url_for('static', filename='icons/icon-48x48.png') }}">
    <link rel="apple-touch-icon" sizes="72x72" href="{{ url_for('static', filename='icons/icon-72x72.png') }}">
    <link rel="apple-touch-icon" sizes="96x96" href="{{ url_for('static', filename='icons/icon-96x96.png') }}">
    <link rel="apple-touch-icon" sizes="144x144" href="{{ url_for('static', filename='icons/icon-144x144.png') }}">
    <link rel="apple-touch-icon" sizes="192x192" href="{{ url_for('static', filename='icons/icon-192x192.png') }}">
    <link rel="apple-touch-icon" sizes="384x384" href="{{ url_for('static', filename='icons/icon-384x384.png') }}">
    <link rel="apple-touch-icon" sizes="512x512" href="{{ url_for('static', filename='icons/icon-512x512.png') }}">
  
</head>

<body>
    <!-- منوی کشویی -->
    <div class="menu-container">
        <div class="hamburger" onclick="toggleMenu()">
            <div class="line"></div>
            <div class="line"></div>
            <div class="line"></div>
        </div>
        
        <div class="sidebar" id="sidebar">
            <div class="close-btn" onclick="toggleMenu()">×</div>
            <ul>
               
                <li class="info-item">
                    <span class="creator-info">سازنده: امیرحسین خزاعی</span>
                </li>
                <li class="info-item">
                    <span class="creator-info">ایمیل: amirhossinpython03@gmail.com</span>
                </li>
                <li><button onclick="toggleDarkMode()" id="darkModeBtn">حالت شب</button></li>
            </ul>
        </div>
    </div>

    
    <div class="main-content" id="mainContent">
        <div class="container">
            <h1>تبدیل متن به خطوط باستانی</h1>
            
            <div class="input-group">
                <textarea id="inputText" placeholder="متن خود را وارد کنید..."></textarea>
                <div class="char-counter"><span id="charCount">0</span>/500</div>
            </div>

            <div class="select-group">
                <select id="languageSelect">
                    <option value="pahlavi">پهلوی</option>
                    <option value="cuneiform">خط میخی</option>
                    <option value="manichaean">مانوی</option>
                    <option value="hieroglyph">هیروگلیف</option>
                    <option value="Hebrew">عبری</option>
                    <option value="linear_b_optimized">خط Linear B</option>
                    <option value="sanskrit">سانسکریت</option>
                    <option value="akkadian">اکدی</option>
                    <option value="oracle_bone">چینی باستان</option>
                    <option value="avestan"> اوستایی</option>
                    <option value="brahmi">براهمی</option>


                    
                    
                </select>
            </div>

            <button id="convertBtn" onclick="convertText()">تبدیل متن</button>

            <div class="result-container">
                <h2>نتیجه تبدیل:</h2>
                <div class="output-box">
                    <p id="outputText"></p>
                    <button class="copy-btn" onclick="copyText()">
                        <span class="copy-icon">⎘</span>
                        <span class="tooltip">کپی شد!</span>
                    </button>
                </div>
            </div>
        </div>
    </div>

    <!-- اسنک بار (اعلان) -->
    <div id="snackbar">متن با موفقیت کپی شد!</div>
    <script src="{{ url_for('static', filename='script.js') }}"></script>

    <script>
        if ('serviceWorker' in navigator) {
            window.addEventListener('load', function() {
                navigator.serviceWorker.register('/static/service-worker.js').then(function(registration) {
                    console.log('ServiceWorker registration successful with scope: ', registration.scope);
                }, function(err) {
                    console.log('ServiceWorker registration failed: ', err);
                });
            });
        }

        
      
    </script>
</body>
</html>









